@@ -305,7 +305,11 @@ sub dancer_response {
 
         my ($content, $content_type);
 
-        if ( $args->{body} ) {
+        if ( $args->{body} and $args->{files} ) {
+            # XXX: When fixing this, update this method's POD
+            croak 'dancer_response() does not support both body and files';
+        }
+        elsif ( $args->{body} ) {
             $content      = $args->{body};
             $content_type = $args->{content_type}
                 || 'application/x-www-form-urlencoded';
@@ -584,16 +588,19 @@ location.
 
 =head2 dancer_response($method, $path, { params => $params, body => $body, headers => $headers, files => [{filename => '/path/to/file', name => 'my_file'}] })
 
-Returns a Dancer::Response object for the given request.
+Returns a L<< Dancer::Response >> object for the given request.
 
 Only $method and $path are required.
 
 $params is a hashref, $body can be a string or a hashref and $headers can be an arrayref or
-a HTTP::Headers object, $files is an arrayref of hashref, containing some files to upload.
+a L<< HTTP::Headers >> object, $files is an arrayref of hashref, containing some files to upload.
 
 $params always populates the query string, even for POST requests.  $body
 always populates the request body.
 
+Currently, Dancer::Test cannot cope with both I<< body >> and I<< files >>
+passed in the same call.
+
 A good reason to use this function is for testing POST requests. Since POST
 requests may not be idempotent, it is necessary to capture the content and
 status in one shot. Calling the response_status_is and response_content_is
